Welcome to django-haveli-admin’s documentation! — django-haveli-admin 0.1.0 documentation

# Welcome to django-haveli-admin’s documentation!

If you wanted to improve the django default theme to make the admin panel better then you can use django-haveli-admin in your project.

## Requirements

- Django: 2.1 or above

Contents:

- Getting Started
  - Installation
  - Deployment
- Configurations
  - App Icon in Sidebar
  - Brand Image
  - Examples:
- App Config
  - App Icon for Sidebar

# Links

- Django doc: https://docs.djangoproject.com/en/3.1/

- Package: https://pypi.org/project/django-haveli-admin/